from setuptools import setup, find_packages

setup(
    name='discord-user-bots',
    version='0.0.2',
    packages=['discord_user_bot'],
    install_requires=[],
    author='TVOFFicial1',
    author_email='kirill.shishkov2007@gmail.com',
    description='Discord user bot library python',
    url='https://github.com/CCCProo/discord-user-bot',

    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
)
